From 426eeae74eb67934bf7ddcffc07677d93a7ea191 Mon Sep 17 00:00:00 2001
From: Mike <Axe319@gmail.com>
Date: Fri, 8 Oct 2021 17:22:52 -0400
Subject: [PATCH 1/2] Fixed version check to encompass Python 3.10

---
 vpython/__init__.py | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

From 405062dcca5a9a8656b99afb52cd13ce885f8bd1 Mon Sep 17 00:00:00 2001
From: Mike <Axe319@gmail.com>
Date: Mon, 11 Oct 2021 18:16:50 -0400
Subject: [PATCH 2/2] Added username to contributors.md

---
 CONTRIBUTORS.md | 1 +
 1 file changed, 1 insertion(+)

diff --git a/CONTRIBUTORS.md b/CONTRIBUTORS.md
index 1f627bd..d608966 100644
--- a/CONTRIBUTORS.md
+++ b/CONTRIBUTORS.md
@@ -30,6 +30,7 @@ We are certain the list is incomplete; please let one of us know by opening an [
 + Kyle Dunn ([@kdunn926](https://github.com/kdunn926))
 + Brian Su ([@brianbbsu](https://github.com/brianbbsu))
 + [@0dminnimda](https://github.com/0dminnimda)
++ Mike Miller ([@Axe319](https://github.com/axe319))
 
 ## Full timeline of vpython development
 

diff --git a/vpython/__init__.py b/vpython/__init__.py
index 3fc6ce5..c09f697 100644
--- a/vpython/__init__.py
+++ b/vpython/__init__.py
@@ -10,14 +10,14 @@
 # both of those.
 
 from ._notebook_helpers import _isnotebook, __is_spyder
-import platform
-__p = platform.python_version()
+import sys
+__v = sys.version_info
 
-# Delete platform now that we are done with it
-del platform
+# Delete sys now that we are done with it
+del sys
 
-__ispython3 = (__p[0] == '3')
-__require_notebook = (not __ispython3) or (__p[2] < '5') # Python 2.7 or 3.4 require Jupyter notebook
+__ispython3 = (__v.major == 3)
+__require_notebook = (not __ispython3) or (__v.minor < 5) # Python 2.7 or 3.4 require Jupyter notebook
 
 if __require_notebook and (not _isnotebook):
         s = "The non-notebook version of vpython requires Python 3.5 or later."
